@@ -13,7 +13,9 @@ function(point, formula, cat.var, data.f, range, min.p.cat ) {
 			if("try-error" %in% class(fit)) {
 				cpe <- NA
 			} else {
-				cpe <- phcpe2(coef = fit$coefficients, coef.var = fit$var, design = model.matrix(fit, data = data.f))$CPE #phcpe(fit, CPE.SE=FALSE, out.ties=FALSE)$CPE      
+				cpe <- coxcpe(fit, data.f)
+				#phcpe(fit, CPE.SE=FALSE, out.ties=FALSE)$CPE      
+				#phcpe2(coef = fit$coefficients, coef.var = fit$var, design = model.matrix(fit, data = data.f))$CPE 
 			}
 		} else {
 			cpe <- NA
